@@ -22,7 +22,7 @@
 #'    \tab \cr
 #'    With \code{DynForestVIMP} \tab the VIMP for each predictor \cr
 #'    \tab \cr
-#'    With \code{DynForestVarDepth} \tab the grouped-VIMP for each given group \cr
+#'    With \code{DynForestgVIMP} \tab the grouped-VIMP for each given group \cr
 #' }
 #'
 #' @examples
@@ -72,7 +72,7 @@
 #'                      ntree = 50, nodesize = 5, minsplit = 5,
 #'                      cause = 2, ncores = 2, seed = 1234)
 #'
-#' # Plot minimal depth
+#' # Plot estimated CIF at nodes 17 and 32
 #' plot(x = res_dyn, tree = 1, nodes = c(17,32))
 #'
 #' # Run var_depth function
@@ -111,7 +111,7 @@
 #'                     idVar = "id", timeVar = "time",
 #'                     t0 = 4)
 #'
-#' # Display CIF for subjects 26 and 110
+#' # Plot predicted CIF for subjects 26 and 110
 #' plot(x = pred_dyn, id = c(26, 110))
 #'
 #' }
@@ -138,10 +138,10 @@ plot.DynForest <- function(x, tree = NULL, nodes = NULL, id = NULL, max_tree = N
       if (!all(inherits(nodes, "numeric"))){
         stop("'nodes' should be a numeric object containing the tree identifier!")
       }
-      if (any(nodes>length(x$rf[,tree]$Y_pred))){
+      if (!all(nodes%in%names(x$rf[,tree]$Y_pred))){
         stop("One selected node do not have CIF! Please verify the 'nodes' identifiers!")
       }
-      if (any(sapply(nodes, FUN = function(node) is.null(x$rf[,tree]$Y_pred[[node]])))){
+      if (any(sapply(nodes, FUN = function(node) is.null(x$rf[,tree]$Y_pred[[as.character(node)]])))){
         stop("One selected node do not have CIF! Please verify the 'nodes' identifiers!")
       }
     }else{
@@ -151,7 +151,7 @@ plot.DynForest <- function(x, tree = NULL, nodes = NULL, id = NULL, max_tree = N
     # data transformation for ggplot2
     CIFs_nodes_list <- lapply(nodes, FUN = function(node){
 
-      CIFs_node <- x$rf[,tree]$Y_pred[[node]]
+      CIFs_node <- x$rf[,tree]$Y_pred[[as.character(node)]]
 
       CIFs_node_list <- lapply(names(CIFs_node), FUN = function(y){
 
@@ -198,7 +198,7 @@ plot.DynForest <- function(x, tree = NULL, nodes = NULL, id = NULL, max_tree = N
         next()
       }
 
-      CIFs_node <- x$rf[,tree_id]$Y_pred[[tree_node]]
+      CIFs_node <- x$rf[,tree_id]$Y_pred[[as.character(tree_node)]]
 
       CIFs_node_list <- lapply(names(CIFs_node), FUN = function(y){
 
